==> moodle-1.5-mysql.tgz: moodle/lang/nl/attendance.php <==
<?PHP // $Id$ 
      // attendance.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004093001)


$string['absentlong'] = 'Afwezig';
$string['absentshort'] = '-';
$string['addingmultiple'] = 'Verschillende aanwezigheidslijsten toevoegen';
$string['addmultiple'] = 'Voeg verschillende aanwezigheidslijsten toe';
$string['allmodulename'] = 'Alle aanwezigheidslijsten';
$string['auto'] = 'auto';
$string['autoattend'] = 'Neem automatisch aanwezigheid op, op basis van de logbestanden van gebruikersactiviteit';
$string['autoattendmulti'] = 'Neem automatisch aanwezigheid op voor alle aanwezigheidslijsten op basis van de logbestanden van gebruikersactiviteit';
$string['autoattendshort'] = 'Automatisch uit logbestanden';
$string['choosedays'] = 'Dagen van de week om aanwezigheid op te nemen';
$string['dayofroll'] = 'Datum voor de lijst';
$string['defaultautoattend'] = 'Aanwezigheid opnemen, gebaseerd op logbestanden van gebruikersactiviteit, als standaard instellen';
$string['defaultdynamicsection'] = 'Aanwezigheidslijsten standaard naar de juiste week verplaatsen';
$string['defaultgrade'] = 'Aanwezigheidslijsten standaard op punten zetten';
$string['defaulthoursinclass'] = 'Standaard aantal uur in een aanwezigheidslijst';
$string['defaultmaxgrade'] = 'Maximumcijfer voor iemand die nooit afwezig is geweest';
$string['defaultstudentstatus'] = 'De standaardstatus van een leerling op aanwezigheidslijsten';
$string['downloadexcelfull'] = 'Download volledig Excel-blad';
$string['downloadexceltotals'] = 'Download samenvattend Excel-blad';
$string['downloadtextfull'] = 'Download volledig tekstrapport';
$string['downloadtexttotals'] = 'Download samenvattend tekstrapport';
$string['dynamicsection'] = 'De week voor het nemen van aanwezigheid bepalen op de datum van vandaag';
$string['dynamicsectionmulti'] = 'Plaats de aanwezigheidslijsten automatisch in de juiste weeksectie';
$string['dynsectionshort'] = 'Dynamisch verplaatst naar sectie';
$string['endbeforestart'] = 'De einddatum is voor de startdatum';
$string['endmulti'] = 'Datum voor de laatste aanwezigheidslijst';
$string['for'] = 'voor';
$string['friday'] = 'Vr';
$string['gradeshort'] = 'Punten gegeven';
$string['gradevalue'] = 'Zet deze lijst op punten';
$string['gradevaluemulti'] = 'Zet deze lijsten op punten';
$string['hoursinclass'] = 'Aantal uren in een lesperiode';
$string['hoursineachclass'] = 'Aantal uren in elke lesperiode';
$string['hoursinfullreport'] = 'Het maximum aantal uren aanwezigheid dat op een afzonderlijke pagina van het een rapport moet staan';
$string['maxgradeshort'] = 'Maximumcijfer';
$string['maxgradevalue'] = 'Maximale cijferwaarde voor altijd aanwezig';
$string['modulename'] = 'Aanwezigheid';
$string['modulenameplural'] = 'Aanwezigheidslijsten';
$string['monday'] = 'Ma';
$string['norolls'] = 'Er zijn geen aanwezigheidslijsten in dit vak';
$string['notes'] = 'Uitzonderingsinformatie';
$string['notesfor'] = 'Uitzonderingsinformatie voor';
$string['noviews'] = 'Sorry, er zijn hier geen gegevens voor je account';
$string['of'] = 'van';
$string['pages'] = 'Pagina\"s';
$string['presentlong'] = 'Aanwezig';
$string['presentshort'] = 'A';
$string['saturday'] = 'Za';
$string['startafterend'] = 'De begindatum is na het einde van het vak';
$string['startmulti'] = 'Datum voor de eerste aanwezigheidslijst';
$string['sunday'] = 'Zo';
$string['takeroll'] = 'Maak een aanwezigheidslijst op deze dag?';
$string['tardiesperabsence'] = 'Hoe vaak te laat komen telt als n keer afwezig?';
$string['tardylong'] = 'Te laat';
$string['tardyshort'] = 'L';
$string['teacheredit'] = 'Noteer aanwezigheid';
$string['thursday'] = 'Do';
$string['tuesday'] = 'Di';
$string['viewall'] = 'Toon alle aanwezigheidslijsten';
$string['viewmulti'] = 'Toon het rapport als meer pagina\'s';
$string['viewone'] = 'Toon alle pagina\'s van het rapport';
$string['viewsection'] = 'Toon alle aanwezigheidslijsten van deze sectie';
$string['viewtable'] = 'Toon het rapport als n tabel';
$string['viewweek'] = 'Toon alle aanwezigheidslijsten van de kalenderweek';
$string['wednesday'] = 'Wo';
$string['weekmodulename'] = 'Alle aanwezigheidslijsten van de laatste week';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/nl/attendance.php <==
<?PHP // $Id$ 
      // attendance.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004093001)


$string['absentlong'] = 'Afwezig';
$string['absentshort'] = '-';
$string['addingmultiple'] = 'Verschillende aanwezigheidslijsten toevoegen';
$string['addmultiple'] = 'Voeg verschillende aanwezigheidslijsten toe';
$string['allmodulename'] = 'Alle aanwezigheidslijsten';
$string['auto'] = 'auto';
$string['autoattend'] = 'Neem automatisch aanwezigheid op, op basis van de logbestanden van gebruikersactiviteit';
$string['autoattendmulti'] = 'Neem automatisch aanwezigheid op voor alle aanwezigheidslijsten op basis van de logbestanden van gebruikersactiviteit';
$string['autoattendshort'] = 'Automatisch uit logbestanden';
$string['choosedays'] = 'Dagen van de week om aanwezigheid op te nemen';
$string['dayofroll'] = 'Datum voor de lijst';
$string['defaultautoattend'] = 'Aanwezigheid opnemen, gebaseerd op logbestanden van gebruikersactiviteit, als standaard instellen';
$string['defaultdynamicsection'] = 'Aanwezigheidslijsten standaard naar de juiste week verplaatsen';
$string['defaultgrade'] = 'Aanwezigheidslijsten standaard op punten zetten';
$string['defaulthoursinclass'] = 'Standaard aantal uur in een aanwezigheidslijst';
$string['defaultmaxgrade'] = 'Maximumcijfer voor iemand die nooit afwezig is geweest';
$string['defaultstudentstatus'] = 'De standaardstatus van een leerling op aanwezigheidslijsten';
$string['downloadexcelfull'] = 'Download volledig Excel-blad';
$string['downloadexceltotals'] = 'Download samenvattend Excel-blad';
$string['downloadtextfull'] = 'Download volledig tekstrapport';
$string['downloadtexttotals'] = 'Download samenvattend tekstrapport';
$string['dynamicsection'] = 'De week voor het nemen van aanwezigheid bepalen op de datum van vandaag';
$string['dynamicsectionmulti'] = 'Plaats de aanwezigheidslijsten automatisch in de juiste weeksectie';
$string['dynsectionshort'] = 'Dynamisch verplaatst naar sectie';
$string['endbeforestart'] = 'De einddatum is voor de startdatum';
$string['endmulti'] = 'Datum voor de laatste aanwezigheidslijst';
$string['for'] = 'voor';
$string['friday'] = 'Vr';
$string['gradeshort'] = 'Punten gegeven';
$string['gradevalue'] = 'Zet deze lijst op punten';
$string['gradevaluemulti'] = 'Zet deze lijsten op punten';
$string['hoursinclass'] = 'Aantal uren in een lesperiode';
$string['hoursineachclass'] = 'Aantal uren in elke lesperiode';
$string['hoursinfullreport'] = 'Het maximum aantal uren aanwezigheid dat op een afzonderlijke pagina van het een rapport moet staan';
$string['maxgradeshort'] = 'Maximumcijfer';
$string['maxgradevalue'] = 'Maximale cijferwaarde voor altijd aanwezig';
$string['modulename'] = 'Aanwezigheid';
$string['modulenameplural'] = 'Aanwezigheidslijsten';
$string['monday'] = 'Ma';
$string['norolls'] = 'Er zijn geen aanwezigheidslijsten in deze cursus';
$string['notes'] = 'Uitzonderingsinformatie';
$string['notesfor'] = 'Uitzonderingsinformatie voor';
$string['noviews'] = 'Sorry, er zijn hier geen gegevens voor je account';
$string['of'] = 'van';
$string['pages'] = 'Pagina\'s';
$string['presentlong'] = 'Aanwezig';
$string['presentshort'] = 'A';
$string['saturday'] = 'Za';
$string['startafterend'] = 'De begindatum van de aanwezigheidslijsten is na de einddatum van de curus';
$string['startmulti'] = 'Datum voor de eerste aanwezigheidslijst';
$string['sunday'] = 'Zo';
$string['takeroll'] = 'Maak een aanwezigheidslijst op deze dag?';
$string['tardiesperabsence'] = 'Hoe vaak te laat komen telt als n keer afwezig?';
$string['tardylong'] = 'Te laat';
$string['tardyshort'] = 'L';
$string['teacheredit'] = 'Noteer aanwezigheid';
$string['thursday'] = 'Do';
$string['tuesday'] = 'Di';
$string['viewall'] = 'Toon alle aanwezigheidslijsten';
$string['viewmulti'] = 'Toon het rapport als meer pagina\'s';
$string['viewone'] = 'Toon alle pagina\'s van het rapport';
$string['viewsection'] = 'Toon alle aanwezigheidslijsten van deze sectie';
$string['viewtable'] = 'Toon het rapport als n tabel';
$string['viewweek'] = 'Toon alle aanwezigheidslijsten van de kalenderweek';
$string['wednesday'] = 'Wo';
$string['weekmodulename'] = 'Alle aanwezigheidslijsten van de laatste week';

?>
